@@ -1,6 +1,7 @@
 
+
 update.trellis <-
-    function(foo,
+    function(object,
              aspect,
              as.table,
              between,
@@ -17,42 +18,43 @@ update.trellis <-
              xlab,
              xlim,
              ylab,
-             ylim)
+             ylim,
+             ...)
 {
     
     if(!missing(aspect)){
         if (is.numeric(aspect)){
-            foo$aspect.ratio <- aspect
-            foo$aspect.fill <- FALSE
+            object$aspect.ratio <- aspect
+            object$aspect.fill <- FALSE
         }
         else if (is.character(aspect) && aspect=="fill")
-            foo$aspect.fill <- TRUE
+            object$aspect.fill <- TRUE
         else warning("Inappropriate value of aspect")
     }
     
     if(!missing(as.table)){
-        if (is.logical(as.table)) foo$as.table <- as.table
+        if (is.logical(as.table)) object$as.table <- as.table
         else warning("Inappropriate value of as.table")
     }
     
     if(!missing(between)){
-        if ("x" %in% names(between)) foo$x.between <- between$x
-        if ("y" %in% names(between)) foo$y.between <- between$y
+        if ("x" %in% names(between)) object$x.between <- between$x
+        if ("y" %in% names(between)) object$y.between <- between$y
     }
     
     if(!missing(key)){
-        foo$key <- key
+        object$key <- key
     }
     
     if(!missing(layout)){
         if (length(layout)==2){
-            foo$layout[3] <- ceiling(foo$layout[1]*foo$layout[2]*foo$layout[3]/
+            object$layout[3] <- ceiling(object$layout[1]*object$layout[2]*object$layout[3]/
                                      max(layout[1]*layout[2], layout[2]))
-            foo$layout[1] <- layout[1]
-            foo$layout[2] <- layout[2]
+            object$layout[1] <- layout[1]
+            object$layout[2] <- layout[2]
         }
         else if (length(layout)==3){
-            foo$layout <- layout
+            object$layout <- layout
         }
         else warning("Inappropriate value of layout")
     }
@@ -62,67 +64,72 @@ update.trellis <-
     
     if(!missing(main)){
         if (is.character(main))
-            if (is.null(foo$main)) foo$main <-
+            if (is.null(object$main)) object$main <-
                 list(label = main, col = "black", cex = 1, font = 1)
-            else foo$main$label <- main
+            else object$main$label <- main
 
         else if (is.list(main)) {
-            foo$main[names(main)] <- main
+            object$main[names(main)] <- main
         }
-        else if (is.null(main)) foo$main <- NULL
+        else if (is.null(main)) object$main <- NULL
     }
     
     if(!missing(sub)){
         if (is.character(sub))
-            if (is.null(foo$sub)) foo$sub <-
+            if (is.null(object$sub)) object$sub <-
                 list(label = sub, col = "black", cex = 1, font = 1)
-            else foo$sub$label <- sub
+            else object$sub$label <- sub
 
         else if (is.list(sub)) {
-            foo$sub[names(sub)] <- sub
+            object$sub[names(sub)] <- sub
         }
-        else if (is.null(sub)) foo$sub <- NULL
+        else if (is.null(sub)) object$sub <- NULL
     }
     
     if(!missing(xlab)){
         if (is.character(xlab))
-            if (is.null(foo$xlab)) foo$xlab <-
+            if (is.null(object$xlab)) object$xlab <-
                 list(label = xlab, col = "black", cex = 1, font = 1)
-            else foo$xlab$label <- xlab
+            else object$xlab$label <- xlab
 
         else if (is.list(xlab)) {
-            foo$xlab[names(xlab)] <- xlab
+            object$xlab[names(xlab)] <- xlab
         }
-        else if (is.null(xlab)) foo$xlab <- NULL
+        else if (is.null(xlab)) object$xlab <- NULL
     }
     
     if(!missing(ylab)){
         if (is.character(ylab))
-            if (is.null(foo$ylab)) foo$ylab <-
+            if (is.null(object$ylab)) object$ylab <-
                 list(label = ylab, col = "black", cex = 1, font = 1)
-            else foo$ylab$label <- ylab
+            else object$ylab$label <- ylab
 
         else if (is.list(ylab)) {
-            foo$ylab[names(ylab)] <- ylab
+            object$ylab[names(ylab)] <- ylab
         }
-        else if (is.null(ylab)) foo$ylab <- NULL
+        else if (is.null(ylab)) object$ylab <- NULL
     }
     
 
     
     if(!missing(page)){
-        foo$page <- page
+        object$page <- page
     }
     
     if(!missing(panel)){
-        if (foo$fname == "splom")
-            foo$panel.args.common$panel <- panel
-        else foo$panel <- panel
+        panel <- 
+            if (is.function(panel)) panel 
+            else if (is.character(panel)) get(panel)
+            else eval(panel)
+
+        if (object$fname == "splom")
+            object$panel.args.common$panel <- panel
+        else object$panel <- panel
     }
     
     if(!missing(par.strip.text)){
         if (is.list(par.strip.text))
-            foo$par.strip.text[names(par.strip.text)] <-
+            object$par.strip.text[names(par.strip.text)] <-
                 par.strip.text
         else warning("par.strip.text must be a list")
     }
@@ -133,19 +140,19 @@ update.trellis <-
     
     if(!missing(strip)){
         if (is.logical(strip)){
-            if (strip) foo$strip <- strip.default
-        else foo$strip <- FALSE
+            if (strip) object$strip <- strip.default
+        else object$strip <- FALSE
         }
-        else foo$strip <- strip
+        else object$strip <- strip
     }
     
     if(!missing(xlim)){
-        if (foo$x.relation.same) foo$x.scales$limits <- xlim
+        if (!is.list(object$x.limits)) object$x.limits <- xlim
         else warning("xlim cannot be specified unless relation = same")
     }
     
     if(!missing(ylim)){
-        if (foo$y.relation.same) foo$y.scales$limits <- ylim
+        if (!is.list(object$y.limits)) object$y.limits <- ylim
         else warning("ylim cannot be specified unless relation = same")
     }
 
@@ -160,16 +167,16 @@ update.trellis <-
         if ("alternating" %in% names(scales)){
             if (is.logical(scales$alternating))
                 if (scales$alternating){
-                    foo$x.alternating <- c(1,2)
-                    foo$y.alternating <- c(1,2)
+                    object$x.scales$alternating <- c(1,2)
+                    object$y.scales$alternating <- c(1,2)
                 }
                 else {
-                    foo$x.alternating <- 1
-                    foo$y.alternating <- 1
+                    object$x.scales$alternating <- 1
+                    object$y.scales$alternating <- 1
                 }
             else if (is.numeric(scales$alternating)) {
-                foo$x.alternating <- scales$alternating
-                foo$y.alternating <- scales$alternating
+                object$x.scales$alternating <- scales$alternating
+                object$y.scales$alternating <- scales$alternating
             }
         }
         
@@ -180,13 +187,13 @@ update.trellis <-
             "alternating" %in% names(scales$x)){
             if (is.logical(scales$x$alternating))
                 if (scales$x$alternating){
-                    foo$x.alternating <- c(1,2)
+                    object$x.scales$alternating <- c(1,2)
                 }
                 else {
-                    foo$x.alternating <- 1
+                    object$x.scales$alternating <- 1
                 }
             else if (is.numeric(scales$x$alternating)) {
-                foo$x.alternating <- scales$x$alternating
+                object$x.scales$alternating <- scales$x$alternating
             }
         }
         
@@ -198,45 +205,36 @@ update.trellis <-
             "alternating" %in% names(scales$y)){
             if (is.logical(scales$y$alternating))
                 if (scales$y$alternating){
-                    foo$y.alternating <- c(1,2)
+                    object$y.scales$alternating <- c(1,2)
                 }
                 else {
-                    foo$y.alternating <- 1
+                    object$y.scales$alternating <- 1
                 }
             else if (is.numeric(scales$y$alternating)) {
-                foo$y.alternating <- scales$y$alternating
+                object$y.scales$alternating <- scales$y$alternating
             }
         }
-        
-        
-        
-        if (foo$x.relation.same){
-            foo$x.scales[names(scales)] <- scales
-            if ("x" %in% names(scales)){
+
+
+        object$x.scales[names(scales)] <- scales
+        if ("x" %in% names(scales)){
                 
-                foo$x.scales[names(scales$x)] <- scales$x
+            object$x.scales[names(scales$x)] <- scales$x
                 
-                if ("relation" %in% names(scales$x))
-                    warning("relation cannot be changed via update")
-            }
+            if ("relation" %in% names(scales$x))
+                warning("relation cannot be changed via update")
         }
-        else
-            warning("sorry, x-scales cannot be changed unless x-relation = same")
         
-        if (foo$y.relation.same){
-            foo$y.scales[names(scales)] <- scales
-            if ("y" %in% names(scales)){
+        object$y.scales[names(scales)] <- scales
+        if ("y" %in% names(scales)){
                 
-                foo$y.scales[names(scales$y)] <- scales$y
+            object$y.scales[names(scales$y)] <- scales$y
                 
-                if ("relation" %in% names(scales$y))
-                    warning("relation cannot be changed via update")
-            }
+            if ("relation" %in% names(scales$y))
+                warning("relation cannot be changed via update")
         }
-        else
-            warning("sorry, y-scales cannot be changed unless y-relation = same")
+
     }
 
-
-    foo
+    object
 }
